@@ -29,6 +29,9 @@ def mock_post(fs):
                 """
 <!DOCTYPE html><html lang="en">
 <head>
+<meta content="article" property="og:type"/>
+<meta content="Post title" property="og:title"/>
+<meta content="This is the post description" property="og:description"/>
 <link href="{{ config.webmention.endpoint }}" rel="webmention" />
 <link href="https://external.example.com/css/basic.css" rel="stylesheet">
 <link href="/css/style.css" rel="stylesheet">
